@@ -1,4 +1,7 @@
+from __future__ import annotations
+
 import inspect
+import warnings
 from collections.abc import Sequence
 
 import numpy as np
@@ -9,9 +12,11 @@ try:
 except ImportError:
     scipy = None
 
-from ..utils import derived_from, skip_doctest
-from .core import concatenate as _concatenate
-from .creation import arange as _arange
+from dask.array.core import asarray
+from dask.array.core import concatenate as _concatenate
+from dask.array.creation import arange as _arange
+from dask.array.numpy_compat import NUMPY_GE_200
+from dask.utils import derived_from, skip_doctest
 
 chunk_error = (
     "Dask array only supports taking an FFT along an axis that \n"
@@ -154,6 +159,7 @@ def fft_wrap(fft_func, kind=None, dtype=None):
         raise ValueError("Given unknown `kind` %s." % kind)
 
     def func(a, s=None, axes=None):
+        a = asarray(a)
         if axes is None:
             if kind.endswith("2"):
                 axes = (-2, -1)
@@ -161,6 +167,13 @@ def fft_wrap(fft_func, kind=None, dtype=None):
                 if s is None:
                     axes = tuple(range(a.ndim))
                 else:
+                    if NUMPY_GE_200:
+                        # Match deprecation in numpy
+                        warnings.warn(
+                            "DeprecationWarning: `axes` should not be `None` "
+                            "if `s` is not `None` (Deprecated in NumPy 2.0)",
+                            DeprecationWarning,
+                        )
                     axes = tuple(range(len(s)))
             else:
                 axes = (-1,)
@@ -193,7 +206,7 @@ def fft_wrap(fft_func, kind=None, dtype=None):
     if kind.endswith("fft"):
         _func = func
 
-        def func(a, n=None, axis=None):  # type: ignore
+        def func(a, n=None, axis=None):
             s = None
             if n is not None:
                 s = (n,)
