@@ -1,14 +1,16 @@
-import random
+from __future__ import annotations
 
 import numpy as np
 import pytest
-from packaging.version import parse as parse_version
+from packaging.version import Version
 
 import dask
 import dask.array as da
+from dask.array.reductions import nannumel, numel
 from dask.array.utils import assert_eq
 
 sparse = pytest.importorskip("sparse")
+SPARSE_VERSION = Version(sparse.__version__)
 if sparse:
     # Test failures on older versions of Numba.
     # Conda-Forge provides 0.35.0 on windows right now, causing failures like
@@ -21,7 +23,7 @@ functions = [
     lambda x: da.expm1(x),
     lambda x: 2 * x,
     lambda x: x / 2,
-    lambda x: x ** 2,
+    lambda x: x**2,
     lambda x: x + x,
     lambda x: x * x,
     lambda x: x[0],
@@ -29,27 +31,26 @@ functions = [
     lambda x: x[:1, None, 1:3],
     lambda x: x.T,
     lambda x: da.transpose(x, (1, 2, 0)),
+    lambda x: da.nanmean(x),
+    lambda x: da.nanmean(x, axis=1),
+    lambda x: da.nanmax(x),
+    lambda x: da.nanmin(x),
+    lambda x: da.nanprod(x),
+    lambda x: da.nanstd(x),
+    lambda x: da.nanvar(x),
+    lambda x: da.nansum(x),
+    # These nan* variants are are not implemented by sparse.COO
+    # lambda x: da.median(x, axis=0),
+    # lambda x: da.nanargmax(x),
+    # lambda x: da.nanargmin(x),
+    # lambda x: da.nancumprod(x, axis=0),
+    # lambda x: da.nancumsum(x, axis=0),
     lambda x: x.sum(),
-    pytest.param(
-        lambda x: x.mean(),
-        marks=pytest.mark.skipif(
-            parse_version(sparse.__version__) >= parse_version("0.12.0"),
-            reason="https://github.com/dask/dask/issues/7169",
-        ),
-    ),
     lambda x: x.moment(order=0),
-    pytest.param(
-        lambda x: x.std(),
-        marks=pytest.mark.xfail(
-            reason="fixed in https://github.com/pydata/sparse/pull/243"
-        ),
-    ),
-    pytest.param(
-        lambda x: x.var(),
-        marks=pytest.mark.xfail(
-            reason="fixed in https://github.com/pydata/sparse/pull/243"
-        ),
-    ),
+    lambda x: x.mean(),
+    lambda x: x.mean(axis=1),
+    lambda x: x.std(),
+    lambda x: x.var(),
     lambda x: x.dot(np.arange(x.shape[-1])),
     lambda x: x.dot(np.eye(x.shape[-1])),
     lambda x: da.tensordot(x, np.ones(x.shape[:2]), axes=[(0, 1), (0, 1)]),
@@ -58,8 +59,8 @@ functions = [
     lambda x: x.sum(axis=(1, 2)),
     lambda x: x.astype(np.complex128),
     lambda x: x.map_blocks(lambda x: x * 2),
-    lambda x: x.map_overlap(lambda x: x * 2, depth=0, trim=True),
-    lambda x: x.map_overlap(lambda x: x * 2, depth=0, trim=False),
+    lambda x: x.map_overlap(lambda x: x * 2, depth=0, trim=True, boundary="none"),
+    lambda x: x.map_overlap(lambda x: x * 2, depth=0, trim=False, boundary="none"),
     lambda x: x.round(1),
     lambda x: x.reshape((x.shape[0] * x.shape[1], x.shape[2])),
     lambda x: abs(x),
@@ -68,6 +69,27 @@ functions = [
     lambda x: x.rechunk((2, 2, 1)),
     lambda x: np.isneginf(x),
     lambda x: np.isposinf(x),
+    pytest.param(
+        lambda x: np.zeros_like(x),
+        marks=pytest.mark.xfail(
+            SPARSE_VERSION < Version("0.13.0"),
+            reason="https://github.com/pydata/xarray/issues/5654",
+        ),
+    ),
+    pytest.param(
+        lambda x: np.ones_like(x),
+        marks=pytest.mark.xfail(
+            SPARSE_VERSION < Version("0.13.0"),
+            reason="https://github.com/pydata/xarray/issues/5654",
+        ),
+    ),
+    pytest.param(
+        lambda x: np.full_like(x, fill_value=2),
+        marks=pytest.mark.xfail(
+            SPARSE_VERSION < Version("0.13.0"),
+            reason="https://github.com/pydata/xarray/issues/5654",
+        ),
+    ),
 ]
 
 
@@ -81,7 +103,7 @@ def test_basic(func):
     xx = func(x)
     yy = func(y)
 
-    assert_eq(xx, yy)
+    assert_eq(xx, yy, check_meta=False)
 
     if yy.shape:
         zz = yy.compute()
@@ -90,7 +112,7 @@ def test_basic(func):
 
 
 @pytest.mark.skipif(
-    parse_version(sparse.__version__) < parse_version("0.7.0+10"),
+    SPARSE_VERSION < Version("0.7.0+10"),
     reason="fixed in https://github.com/pydata/sparse/pull/256",
 )
 def test_tensordot():
@@ -110,56 +132,6 @@ def test_tensordot():
     )
 
 
-@pytest.mark.xfail(reason="upstream change", strict=False)
-@pytest.mark.parametrize("func", functions)
-def test_mixed_concatenate(func):
-    x = da.random.random((2, 3, 4), chunks=(1, 2, 2))
-
-    y = da.random.random((2, 3, 4), chunks=(1, 2, 2))
-    y[y < 0.8] = 0
-    yy = y.map_blocks(sparse.COO.from_numpy)
-
-    d = da.concatenate([x, y], axis=0)
-    s = da.concatenate([x, yy], axis=0)
-
-    dd = func(d)
-    ss = func(s)
-
-    assert_eq(dd, ss)
-
-
-@pytest.mark.xfail(reason="upstream change", strict=False)
-@pytest.mark.parametrize("func", functions)
-def test_mixed_random(func):
-    d = da.random.random((4, 3, 4), chunks=(1, 2, 2))
-    d[d < 0.7] = 0
-
-    fn = lambda x: sparse.COO.from_numpy(x) if random.random() < 0.5 else x
-    s = d.map_blocks(fn)
-
-    dd = func(d)
-    ss = func(s)
-
-    assert_eq(dd, ss)
-
-
-@pytest.mark.xfail(reason="upstream change", strict=False)
-def test_mixed_output_type():
-    y = da.random.random((10, 10), chunks=(5, 5))
-    y[y < 0.8] = 0
-    y = y.map_blocks(sparse.COO.from_numpy)
-
-    x = da.zeros((10, 1), chunks=(5, 1))
-
-    z = da.concatenate([x, y], axis=1)
-
-    assert z.shape == (10, 11)
-
-    zz = z.compute()
-    assert isinstance(zz, sparse.COO)
-    assert zz.nnz == y.compute().nnz
-
-
 def test_metadata():
     y = da.random.random((10, 10), chunks=(5, 5))
     y[y < 0.8] = 0
@@ -224,3 +196,18 @@ def test_meta_from_array():
     x = sparse.COO.from_numpy(np.eye(1))
     y = da.utils.meta_from_array(x, ndim=2)
     assert isinstance(y, sparse.COO)
+
+
+@pytest.mark.parametrize("numel", [numel, nannumel])
+@pytest.mark.parametrize("axis", [0, (0, 1), None])
+@pytest.mark.parametrize("keepdims", [True, False])
+def test_numel(numel, axis, keepdims):
+    x = np.random.random((2, 3, 4))
+    x[x < 0.8] = 0
+    x[x > 0.9] = np.nan
+
+    xs = sparse.COO.from_numpy(x, fill_value=0.0)
+
+    assert_eq(
+        numel(x, axis=axis, keepdims=keepdims), numel(xs, axis=axis, keepdims=keepdims)
+    )
