@@ -1,19 +1,25 @@
+from __future__ import annotations
+
 import contextlib
 import string
 import warnings
 
+from dask._compatibility import import_optional_dependency
+
+import_optional_dependency("pandas")
+import_optional_dependency("numpy")
+
 import numpy as np
 import pandas as pd
 from packaging.version import Version
 
 PANDAS_VERSION = Version(pd.__version__)
-PANDAS_GT_131 = PANDAS_VERSION >= Version("1.3.1")
-PANDAS_GT_133 = PANDAS_VERSION >= Version("1.3.3")
-PANDAS_GT_140 = PANDAS_VERSION >= Version("1.4.0")
-PANDAS_GT_150 = PANDAS_VERSION >= Version("1.5.0")
-PANDAS_GT_200 = PANDAS_VERSION.major >= 2
-PANDAS_GT_201 = PANDAS_VERSION.release >= (2, 0, 1)
-PANDAS_GT_210 = PANDAS_VERSION.release >= (2, 1, 0)
+PANDAS_GE_201 = PANDAS_VERSION.release >= (2, 0, 1)
+PANDAS_GE_202 = PANDAS_VERSION.release >= (2, 0, 2)
+PANDAS_GE_210 = PANDAS_VERSION.release >= (2, 1, 0)
+PANDAS_GE_211 = PANDAS_VERSION.release >= (2, 1, 1)
+PANDAS_GE_220 = PANDAS_VERSION.release >= (2, 2, 0)
+PANDAS_GE_300 = PANDAS_VERSION.major >= 3
 
 import pandas.testing as tm
 
@@ -81,46 +87,9 @@ def makeMixedDataFrame():
     return df
 
 
-@contextlib.contextmanager
-def check_numeric_only_deprecation(name=None, show_nuisance_warning: bool = False):
-    supported_funcs = ["sum", "median", "prod", "min", "max", "var"]
-    if name not in supported_funcs and PANDAS_GT_150 and not PANDAS_GT_200:
-        with warnings.catch_warnings():
-            warnings.filterwarnings(
-                "ignore",
-                message="The default value of numeric_only",
-                category=FutureWarning,
-            )
-            yield
-    elif (
-        not show_nuisance_warning and name not in supported_funcs and not PANDAS_GT_150
-    ):
-        with warnings.catch_warnings():
-            warnings.filterwarnings(
-                "ignore",
-                message="Dropping of nuisance columns in DataFrame",
-                category=FutureWarning,
-            )
-            yield
-    else:
-        yield
-
-
-@contextlib.contextmanager
-def check_nuisance_columns_warning():
-    if not PANDAS_GT_150:
-        with warnings.catch_warnings(record=True):
-            warnings.filterwarnings(
-                "ignore", "Dropping of nuisance columns", FutureWarning
-            )
-            yield
-    else:
-        yield
-
-
 @contextlib.contextmanager
 def check_groupby_axis_deprecation():
-    if PANDAS_GT_210:
+    if PANDAS_GE_210:
         with warnings.catch_warnings():
             warnings.filterwarnings(
                 "ignore",
@@ -134,7 +103,7 @@ def check_groupby_axis_deprecation():
 
 @contextlib.contextmanager
 def check_observed_deprecation():
-    if PANDAS_GT_210:
+    if PANDAS_GE_210:
         with warnings.catch_warnings():
             warnings.filterwarnings(
                 "ignore",
@@ -148,7 +117,7 @@ def check_observed_deprecation():
 
 @contextlib.contextmanager
 def check_axis_keyword_deprecation():
-    if PANDAS_GT_210:
+    if PANDAS_GE_210:
         with warnings.catch_warnings():
             warnings.filterwarnings(
                 "ignore",
@@ -162,7 +131,7 @@ def check_axis_keyword_deprecation():
 
 @contextlib.contextmanager
 def check_convert_dtype_deprecation():
-    if PANDAS_GT_210:
+    if PANDAS_GE_210:
         with warnings.catch_warnings():
             warnings.filterwarnings(
                 "ignore",
@@ -174,23 +143,9 @@ def check_convert_dtype_deprecation():
         yield
 
 
-@contextlib.contextmanager
-def check_reductions_runtime_warning():
-    if PANDAS_GT_200 and not PANDAS_GT_201:
-        with warnings.catch_warnings():
-            warnings.filterwarnings(
-                "ignore",
-                message="invalid value encountered in double_scalars|Degrees of freedom <= 0 for slice",
-                category=RuntimeWarning,
-            )
-            yield
-    else:
-        yield
-
-
 @contextlib.contextmanager
 def check_to_pydatetime_deprecation(catch_deprecation_warnings: bool):
-    if PANDAS_GT_210 and catch_deprecation_warnings:
+    if PANDAS_GE_210 and catch_deprecation_warnings:
         with warnings.catch_warnings():
             warnings.filterwarnings(
                 "ignore",
@@ -204,7 +159,7 @@ def check_to_pydatetime_deprecation(catch_deprecation_warnings: bool):
 
 @contextlib.contextmanager
 def check_apply_dataframe_deprecation():
-    if PANDAS_GT_210:
+    if PANDAS_GE_210:
         with warnings.catch_warnings():
             warnings.filterwarnings(
                 "ignore",
@@ -218,7 +173,7 @@ def check_apply_dataframe_deprecation():
 
 @contextlib.contextmanager
 def check_applymap_dataframe_deprecation():
-    if PANDAS_GT_210:
+    if PANDAS_GE_210:
         with warnings.catch_warnings():
             warnings.filterwarnings(
                 "ignore",
@@ -230,22 +185,32 @@ def check_applymap_dataframe_deprecation():
         yield
 
 
-if PANDAS_GT_150:
-    IndexingError = pd.errors.IndexingError
-else:
-    IndexingError = pd.core.indexing.IndexingError
+@contextlib.contextmanager
+def check_reductions_runtime_warning():
+    if not PANDAS_GE_201:
+        with warnings.catch_warnings():
+            warnings.filterwarnings(
+                "ignore",
+                message="invalid value encountered in double_scalars|Degrees of freedom <= 0 for slice",
+                category=RuntimeWarning,
+            )
+            yield
+    else:
+        yield
+
+
+IndexingError = pd.errors.IndexingError
 
 
 def is_any_real_numeric_dtype(arr_or_dtype) -> bool:
-    try:
-        # `is_any_real_numeric_dtype` was added in PANDAS_GT_200.
-        # We can remove this compatibility utility once we only support `pandas>=2.0`
-        return pd.api.types.is_any_real_numeric_dtype(arr_or_dtype)
-    except AttributeError:
-        from pandas.api.types import is_bool_dtype, is_complex_dtype, is_numeric_dtype
+    return pd.api.types.is_any_real_numeric_dtype(arr_or_dtype)
 
-        return (
-            is_numeric_dtype(arr_or_dtype)
-            and not is_complex_dtype(arr_or_dtype)
-            and not is_bool_dtype(arr_or_dtype)
-        )
+
+def is_string_dtype(arr_or_dtype) -> bool:
+    # is_string_dtype did not recognize pyarrow strings before 2.0
+    # Can remove once 2.0 is minimum version for us
+    if hasattr(arr_or_dtype, "dtype"):
+        dtype = arr_or_dtype.dtype
+    else:
+        dtype = arr_or_dtype
+    return pd.api.types.is_string_dtype(dtype)
