@@ -289,12 +289,16 @@ def from_pandas(
     if sort:
         if not data.index.is_monotonic_increasing:
             data = data.sort_index(ascending=True)
+        else:
+            # sort_index copies as well
+            data = data.copy()
         divisions, locations = sorted_division_locations(
             data.index,
             npartitions=npartitions,
             chunksize=chunksize,
         )
     else:
+        data = data.copy()
         if chunksize is None:
             assert isinstance(npartitions, int)
             chunksize = int(ceil(nrows / npartitions))
@@ -586,7 +590,22 @@ def from_delayed(
     prefix: str = "from-delayed",
     verify_meta: bool = True,
 ) -> DataFrame | Series:
-    """Create Dask DataFrame from many Dask Delayed objects
+    """Create Dask DataFrame from many Dask Delayed objects.
+
+    .. warning::
+        ``from_delayed`` should only be used if the objects that create
+        the data are complex and cannot be easily represented as a single
+        function in an embarassingly parallel fashion.
+
+        ``from_map`` is recommended if the query can be expressed as a single
+        function like:
+
+        def read_xml(path):
+            return pd.read_xml(path)
+
+        ddf = dd.from_map(read_xml, paths)
+
+        ``from_delayed`` might be depreacted in the future.
 
     Parameters
     ----------
@@ -730,7 +749,7 @@ def sorted_division_locations(seq, npartitions=None, chunksize=None):
         # Map current position selection (i)
         # to the corresponding division value (div)
         div = seq[i]
-        # pos is the position of the first occurance of
+        # pos is the position of the first occurrence of
         # div (which is i when seq has no duplicates)
         if duplicates:
             # Note: cupy requires casts to `int` below
@@ -854,10 +873,13 @@ def from_map(
     enforce_metadata=True,
     **kwargs,
 ):
-    """Create a DataFrame collection from a custom function map
+    """Create a DataFrame collection from a custom function map.
 
-    WARNING: The ``from_map`` API is experimental, and stability is not
-    yet guaranteed. Use at your own risk!
+    ``from_map`` is the preferred option when reading from data sources
+    that are not natively supported by Dask or if the data source
+    requires custom handling before handing things of to Dask DataFrames.
+    Examples are things like binary files or other unstructured data that
+    doesn't have an IO connector.
 
     Parameters
     ----------
@@ -909,13 +931,13 @@ def from_map(
     dtype: object
 
     This API can also be used as an alternative to other file-based
-    IO functions, like ``read_parquet`` (which are already just
+    IO functions, like ``read_csv`` (which are already just
     ``from_map`` wrapper functions):
 
     >>> import pandas as pd
     >>> import dask.dataframe as dd
-    >>> paths = ["0.parquet", "1.parquet", "2.parquet"]
-    >>> dd.from_map(pd.read_parquet, paths).head()  # doctest: +SKIP
+    >>> paths = ["0.csv", "1.csv", "2.csv"]
+    >>> dd.from_map(pd.read_csv, paths).head()  # doctest: +SKIP
                         name
     timestamp
     2000-01-01 00:00:00   Laura
@@ -935,11 +957,11 @@ def from_map(
     >>> import pandas as pd
     >>> import numpy as np
     >>> import dask.dataframe as dd
-    >>> paths = ["0.parquet", "1.parquet", "2.parquet"]
+    >>> paths = ["0.csv", "1.csv", "2.csv"]
     >>> file_sizes = [86400, 86400, 86400]
     >>> def func(path, row_offset):
     ...     # Read parquet file and set RangeIndex offset
-    ...     df = pd.read_parquet(path)
+    ...     df = pd.read_csv(path)
     ...     return df.set_index(
     ...         pd.RangeIndex(row_offset, row_offset+len(df))
     ...     )
@@ -961,7 +983,6 @@ def from_map(
 
     See Also
     --------
-    dask.dataframe.from_delayed
     dask.layers.DataFrameIOLayer
     """
 
