@@ -1,6 +1,9 @@
+from __future__ import annotations
+
 import json
 import operator
 import textwrap
+import warnings
 from collections import defaultdict
 from datetime import datetime
 from functools import reduce
@@ -8,6 +11,7 @@ from functools import reduce
 import numpy as np
 import pandas as pd
 import pyarrow as pa
+import pyarrow.fs as pa_fs
 import pyarrow.parquet as pq
 
 # Check PyArrow version for feature support
@@ -16,10 +20,10 @@ from fsspec.implementations.arrow import ArrowFSWrapper
 from pyarrow import dataset as pa_ds
 from pyarrow import fs as pa_fs
 
-from dask import config
-from dask.base import tokenize
+import dask
+from dask.base import normalize_token, tokenize
 from dask.core import flatten
-from dask.dataframe._compat import check_observed_deprecation
+from dask.dataframe._compat import PANDAS_GE_220
 from dask.dataframe.backends import pyarrow_schema_dispatch
 from dask.dataframe.io.parquet.utils import (
     Engine,
@@ -33,7 +37,7 @@ from dask.dataframe.io.parquet.utils import (
     _sort_and_analyze_paths,
 )
 from dask.dataframe.io.utils import _get_pyarrow_dtypes, _is_local_fs, _open_input_files
-from dask.dataframe.utils import clear_known_categories
+from dask.dataframe.utils import clear_known_categories, pyarrow_strings_enabled
 from dask.delayed import Delayed
 from dask.utils import getargspec, natural_sort_key
 
@@ -53,6 +57,11 @@ PYARROW_NULLABLE_DTYPE_MAPPING = {
 }
 
 
+@normalize_token.register(pa_fs.FileSystem)
+def tokenize_arrowfs(obj):
+    return obj.__reduce__()
+
+
 #
 #  Helper Utilities
 #
@@ -127,8 +136,7 @@ def _write_partitioned(
 
     md_list = []
     partition_keys = partition_keys[0] if len(partition_keys) == 1 else partition_keys
-    with check_observed_deprecation():
-        gb = data_df.groupby(partition_keys, dropna=False)
+    gb = data_df.groupby(partition_keys, dropna=False, observed=False)
     for keys, subgroup in gb:
         if not isinstance(keys, tuple):
             keys = (keys,)
@@ -179,7 +187,10 @@ class PartitionObj:
 
     def __init__(self, name, keys):
         self.name = name
-        self.keys = sorted(keys)
+        self.keys = pd.Index(keys.sort_values(), copy=False)
+
+    def __dask_tokenize__(self):
+        return tokenize(self.name, self.keys)
 
 
 def _frag_subset(old_frag, row_groups):
@@ -453,9 +464,13 @@ class ArrowDatasetEngine(Engine):
                 urlpath = [stringify_path(urlpath)]
 
             if fs in ("arrow", "pyarrow"):
-                fs = type(pa_fs.FileSystem.from_uri(urlpath[0])[0])(
-                    **(storage_options or {})
-                )
+                fs = pa_fs.FileSystem.from_uri(urlpath[0])[0]
+                if storage_options:
+                    # Use inferred region as the default
+                    region = (
+                        {} if "region" in storage_options else {"region": fs.region}
+                    )
+                    fs = type(fs)(**region, **storage_options)
 
             fsspec_fs = ArrowFSWrapper(fs)
             if urlpath[0].startswith("C:") and isinstance(fs, pa_fs.LocalFileSystem):
@@ -490,7 +505,8 @@ class ArrowDatasetEngine(Engine):
         paths,
         categories=None,
         index=None,
-        use_nullable_dtypes=False,
+        use_nullable_dtypes=None,
+        dtype_backend=None,
         gather_statistics=None,
         filters=None,
         split_row_groups="adaptive",
@@ -501,6 +517,31 @@ class ArrowDatasetEngine(Engine):
         parquet_file_extension=None,
         **kwargs,
     ):
+        if use_nullable_dtypes is not None and dtype_backend is not None:
+            raise ValueError(
+                "`use_nullable_dtypes` is deprecated. Use `dtype_backend` keyword argument instead."
+            )
+
+        if use_nullable_dtypes is not None:
+            warnings.warn(
+                "The `use_nullable_dtypes=` keyword argument and `dataframe.dtype_backend` "
+                "config option are deprecated, and will be removed in the future. "
+                "Use the `dtype_backend=` keyword argument instead.",
+                category=FutureWarning,
+            )
+            if use_nullable_dtypes:
+                config_backend = dask.config.get("dataframe.dtype_backend", None)
+                # Meaning of old "pandas" config is now the same as "numpy_nullable"
+                if config_backend in (None, "pandas"):
+                    config_backend = "numpy_nullable"
+                dtype_backend = config_backend
+
+        if dtype_backend not in (None, "numpy_nullable", "pyarrow"):
+            raise ValueError(
+                f"`dtype_backend` should be one of [None, 'numpy_nullable', 'pyarrow'], got {dtype_backend}"
+            )
+        kwargs["dtype_backend"] = dtype_backend
+
         # Stage 1: Collect general dataset information
         dataset_info = cls._collect_dataset_info(
             paths,
@@ -519,9 +560,7 @@ class ArrowDatasetEngine(Engine):
         )
 
         # Stage 2: Generate output `meta`
-        meta = cls._create_dd_meta(
-            dataset_info, use_nullable_dtypes=use_nullable_dtypes
-        )
+        meta = cls._create_dd_meta(dataset_info)
 
         # Stage 3: Generate parts and stats
         parts, stats, common_kwargs = cls._construct_collection_plan(dataset_info)
@@ -547,7 +586,7 @@ class ArrowDatasetEngine(Engine):
         pieces,
         columns,
         index,
-        use_nullable_dtypes=False,
+        dtype_backend=None,
         categories=(),
         partitions=(),
         filters=None,
@@ -618,14 +657,14 @@ class ArrowDatasetEngine(Engine):
 
         # Convert to pandas
         df = cls._arrow_table_to_pandas(
-            arrow_table, categories, use_nullable_dtypes=use_nullable_dtypes, **kwargs
+            arrow_table, categories, dtype_backend=dtype_backend, **kwargs
         )
 
         # For pyarrow.dataset api, need to convert partition columns
         # to categorigal manually for integer types.
         if partitions and isinstance(partitions, list):
             for partition in partitions:
-                if df[partition.name].dtype.name != "category":
+                if len(partition.keys) and df[partition.name].dtype.name != "category":
                     # We read directly from fragments, so the partition
                     # columns are already in our dataframe.  We just
                     # need to convert non-categorical types.
@@ -1096,15 +1135,23 @@ class ArrowDatasetEngine(Engine):
         #          names of partitioned columns.
         #
         partition_obj, partition_names = [], []
-        if (
-            ds.partitioning
-            and ds.partitioning.dictionaries
-            and all(arr is not None for arr in ds.partitioning.dictionaries)
-        ):
+        if ds.partitioning and ds.partitioning.schema:
             partition_names = list(ds.partitioning.schema.names)
             for i, name in enumerate(partition_names):
+                dictionary = (
+                    ds.partitioning.dictionaries[i]
+                    if ds.partitioning.dictionaries
+                    else None
+                )
                 partition_obj.append(
-                    PartitionObj(name, ds.partitioning.dictionaries[i].to_pandas())
+                    PartitionObj(
+                        name,
+                        (
+                            pd.Series([], dtype="object")
+                            if dictionary is None
+                            else dictionary.to_pandas()
+                        ),
+                    )
                 )
 
         # Check the `aggregate_files` setting
@@ -1130,13 +1177,13 @@ class ArrowDatasetEngine(Engine):
             "metadata_task_size": metadata_task_size,
             "kwargs": {
                 "dataset": _dataset_kwargs,
-                "convert_string": config.get("dataframe.convert_string"),
+                "convert_string": pyarrow_strings_enabled(),
                 **kwargs,
             },
         }
 
     @classmethod
-    def _create_dd_meta(cls, dataset_info, use_nullable_dtypes=False):
+    def _create_dd_meta(cls, dataset_info):
         """Use parquet schema and hive-partition information
         (stored in dataset_info) to construct DataFrame metadata.
         """
@@ -1163,12 +1210,13 @@ class ArrowDatasetEngine(Engine):
 
         # Use _arrow_table_to_pandas to generate meta
         arrow_to_pandas = dataset_info["kwargs"].get("arrow_to_pandas", {}).copy()
-        convert_string = dataset_info["kwargs"].get("convert_string", False)
+        convert_string = dataset_info["kwargs"]["convert_string"]
+        dtype_backend = dataset_info["kwargs"]["dtype_backend"]
         meta = cls._arrow_table_to_pandas(
             schema.empty_table(),
             categories,
             arrow_to_pandas=arrow_to_pandas,
-            use_nullable_dtypes=use_nullable_dtypes,
+            dtype_backend=dtype_backend,
             convert_string=convert_string,
         )
         index_names = list(meta.index.names)
@@ -1201,7 +1249,7 @@ class ArrowDatasetEngine(Engine):
             _partitions = [p for p in partitions if p not in physical_column_names]
             if not _partitions:
                 partitions = []
-                dataset_info["partitions"] = None
+                dataset_info["partitions"] = []
                 dataset_info["partition_keys"] = {}
                 dataset_info["partition_names"] = partitions
             elif len(_partitions) != len(partitions):
@@ -1230,12 +1278,16 @@ class ArrowDatasetEngine(Engine):
             # Make sure all categories are set to "unknown".
             # Cannot include index names in the `cols` argument.
             meta = clear_known_categories(
-                meta, cols=[c for c in categories if c not in meta.index.names]
+                meta,
+                cols=[c for c in categories if c not in meta.index.names],
+                dtype_backend=dtype_backend,
             )
 
         if partition_obj:
             # Update meta dtypes for partitioned columns
             for partition in partition_obj:
+                if not len(partition.keys):
+                    continue
                 if isinstance(index, list) and partition.name == index[0]:
                     # Index from directory structure
                     meta.index = pd.CategoricalIndex(
@@ -1321,7 +1373,7 @@ class ArrowDatasetEngine(Engine):
         for i, name in enumerate(schema.names):
             if name in _index_cols or name in filter_columns:
                 if name in partition_names:
-                    # Partition columns wont have statistics
+                    # Partition columns won't have statistics
                     continue
                 stat_col_indices[name] = i
 
@@ -1356,7 +1408,7 @@ class ArrowDatasetEngine(Engine):
                 common_kwargs,
             )
 
-        # Get/transate filters
+        # Get/translate filters
         ds_filters = None
         if filters is not None:
             ds_filters = _filters_to_expression(filters)
@@ -1493,7 +1545,7 @@ class ArrowDatasetEngine(Engine):
         aggregation_depth = dataset_info_kwargs["aggregation_depth"]
         blocksize = dataset_info_kwargs["blocksize"]
 
-        # Intialize row-group and statistics data structures
+        # Initialize row-group and statistics data structures
         file_row_groups = defaultdict(list)
         file_row_group_stats = defaultdict(list)
         file_row_group_column_stats = defaultdict(list)
@@ -1664,7 +1716,7 @@ class ArrowDatasetEngine(Engine):
             frag = None
 
             # Check if we have partitioning information.
-            # Will only have this if the engine="pyarrow-dataset"
+            # Not supported with fastparquet.
             partitioning = kwargs.get("dataset", {}).get("partitioning", None)
 
             # Check if we need to generate a fragment.
@@ -1736,21 +1788,24 @@ class ArrowDatasetEngine(Engine):
             for partition in partitions:
                 if partition.name not in arrow_table.schema.names:
                     # We read from file paths, so the partition
-                    # columns are NOT in our table yet.
+                    # columns may NOT be in our table yet.
                     cat = keys_dict.get(partition.name, None)
-                    cat_ind = np.full(
-                        len(arrow_table), partition.keys.index(cat), dtype="i4"
-                    )
-                    arr = pa.DictionaryArray.from_arrays(
-                        cat_ind, pa.array(partition.keys)
-                    )
+                    if not len(partition.keys):
+                        arr = pa.array(np.full(len(arrow_table), cat))
+                    else:
+                        cat_ind = np.full(
+                            len(arrow_table), partition.keys.get_loc(cat), dtype="i4"
+                        )
+                        arr = pa.DictionaryArray.from_arrays(
+                            cat_ind, pa.array(partition.keys)
+                        )
                     arrow_table = arrow_table.append_column(partition.name, arr)
 
         return arrow_table
 
     @classmethod
     def _determine_type_mapper(
-        cls, *, use_nullable_dtypes=False, convert_string=False, **kwargs
+        cls, *, dtype_backend=None, convert_string=False, **kwargs
     ):
         user_mapper = kwargs.get("arrow_to_pandas", {}).get("types_mapper")
         type_mappers = []
@@ -1758,6 +1813,8 @@ class ArrowDatasetEngine(Engine):
         def pyarrow_type_mapper(pyarrow_dtype):
             # Special case pyarrow strings to use more feature complete dtype
             # See https://github.com/pandas-dev/pandas/issues/50074
+            if PANDAS_GE_220 and pyarrow_dtype == pa.large_string():
+                return pd.StringDtype("pyarrow")
             if pyarrow_dtype == pa.string():
                 return pd.StringDtype("pyarrow")
             else:
@@ -1770,11 +1827,22 @@ class ArrowDatasetEngine(Engine):
         # next in priority is converting strings
         if convert_string:
             type_mappers.append({pa.string(): pd.StringDtype("pyarrow")}.get)
+            if PANDAS_GE_220:
+                type_mappers.append({pa.large_string(): pd.StringDtype("pyarrow")}.get)
+            type_mappers.append({pa.date32(): pd.ArrowDtype(pa.date32())}.get)
+            type_mappers.append({pa.date64(): pd.ArrowDtype(pa.date64())}.get)
+
+            def _convert_decimal_type(type):
+                if pa.types.is_decimal(type):
+                    return pd.ArrowDtype(type)
+                return None
+
+            type_mappers.append(_convert_decimal_type)
 
         # and then nullable types
-        if use_nullable_dtypes == "pandas":
+        if dtype_backend == "numpy_nullable":
             type_mappers.append(PYARROW_NULLABLE_DTYPE_MAPPING.get)
-        elif use_nullable_dtypes:  # "pyarrow" or True
+        elif dtype_backend == "pyarrow":
             type_mappers.append(pyarrow_type_mapper)
 
         def default_types_mapper(pyarrow_dtype):
@@ -1792,7 +1860,7 @@ class ArrowDatasetEngine(Engine):
         cls,
         arrow_table: pa.Table,
         categories,
-        use_nullable_dtypes=False,
+        dtype_backend=None,
         convert_string=False,
         **kwargs,
     ) -> pd.DataFrame:
@@ -1800,7 +1868,7 @@ class ArrowDatasetEngine(Engine):
         _kwargs.update({"use_threads": False, "ignore_metadata": False})
 
         types_mapper = cls._determine_type_mapper(
-            use_nullable_dtypes=use_nullable_dtypes,
+            dtype_backend=dtype_backend,
             convert_string=convert_string,
             **kwargs,
         )
@@ -1840,7 +1908,7 @@ class ArrowDatasetEngine(Engine):
             metadata_path = fs.sep.join([out_path, "_metadata"])
             with fs.open(metadata_path, "wb") as fil:
                 if not meta:
-                    raise ValueError("Cannot write empty metdata!")
+                    raise ValueError("Cannot write empty metadata!")
                 meta.write_metadata_file(fil)
             return None
         else:
