@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import contextlib
 import warnings
 from datetime import datetime
@@ -8,14 +10,7 @@ import pytest
 from pandas.api.types import is_scalar
 
 import dask.dataframe as dd
-from dask.array.numpy_compat import _numpy_125
-from dask.dataframe._compat import (
-    PANDAS_GT_140,
-    PANDAS_GT_150,
-    PANDAS_GT_200,
-    PANDAS_VERSION,
-    check_numeric_only_deprecation,
-)
+from dask.array.numpy_compat import NUMPY_GE_125, NUMPY_GE_200
 from dask.dataframe.utils import (
     assert_dask_graph,
     assert_eq,
@@ -30,10 +25,15 @@ except ImportError:
 
 try:
     import pyarrow as pa
+    from pyarrow.lib import ArrowNotImplementedError
 except ImportError:
     pa = None
+    ArrowNotImplementedError = None
+
+DASK_EXPR_ENABLED = dd._dask_expr_enabled()
 
 
+@pytest.mark.skipif(DASK_EXPR_ENABLED, reason="constructor not supported")
 @pytest.mark.slow
 def test_arithmetics():
     dsk = {
@@ -520,6 +520,7 @@ def test_scalar_arithmetics():
     assert_eq(~(l == r), ~(el == er))
 
 
+@pytest.mark.skipif(DASK_EXPR_ENABLED, reason="scalar not available like this")
 def test_scalar_arithmetics_with_dask_instances():
     s = dd.core.Scalar({("s", 0): 10}, "s", "i8")
     e = 10
@@ -567,10 +568,6 @@ def test_scalar_arithmetics_with_dask_instances():
     assert_eq(result, pdf + e)
 
 
-@pytest.mark.xfail(
-    PANDAS_VERSION == "1.0.2",
-    reason="https://github.com/pandas-dev/pandas/issues/32685",
-)
 def test_frame_series_arithmetic_methods():
     pdf1 = pd.DataFrame(
         {
@@ -594,7 +591,10 @@ def test_frame_series_arithmetic_methods():
     ds1 = ddf1.A
     ds2 = ddf2.A
 
-    s = dd.core.Scalar({("s", 0): 4}, "s", "i8")
+    if DASK_EXPR_ENABLED:
+        s = 4
+    else:
+        s = dd.core.Scalar({("s", 0): 4}, "s", "i8")
 
     for l, r, el, er in [
         (ddf1, ddf2, pdf1, pdf2),
@@ -698,12 +698,15 @@ def test_reductions(split_every):
             index=[9, 9, 9],
         ),
     }
-    meta = make_meta(
-        {"a": "i8", "b": "i8", "c": "bool"},
-        index=pd.Index([], "i8"),
-        parent_meta=pd.DataFrame(),
-    )
-    ddf1 = dd.DataFrame(dsk, "x", meta, [0, 4, 9, 9])
+    if DASK_EXPR_ENABLED:
+        ddf1 = dd.repartition(pd.concat(dsk.values()), divisions=[0, 4, 9, 9])
+    else:
+        meta = make_meta(
+            {"a": "i8", "b": "i8", "c": "bool"},
+            index=pd.Index([], "i8"),
+            parent_meta=pd.DataFrame(),
+        )
+        ddf1 = dd.DataFrame(dsk, "x", meta, [0, 4, 9, 9])
     pdf1 = ddf1.compute()
 
     nans1 = pd.Series([1] + [np.nan] * 4 + [2] + [np.nan] * 3)
@@ -743,15 +746,12 @@ def test_reductions(split_every):
             bias_factor = (n * (n - 1)) ** 0.5 / (n - 2)
             assert_eq(dds.skew(), pds.skew() / bias_factor)
 
-            if PANDAS_GT_200:
-                # TODO: Remove this `if`-block once `axis=None` support is added.
-                # https://github.com/dask/dask/issues/9915
-                with pytest.raises(
-                    ValueError, match="`axis=None` isn't currently supported"
-                ):
-                    dds.skew(axis=None)
-            else:
-                assert_eq(dds.skew(axis=None), pds.skew(axis=None) / bias_factor)
+            # TODO: Remove this `if`-block once `axis=None` support is added.
+            # https://github.com/dask/dask/issues/9915
+            with pytest.raises(
+                ValueError, match="`axis=None` isn't currently supported"
+            ):
+                dds.skew(axis=None)
 
         if scipy:
             # pandas uses a bias factor for kurtosis, need to correct for that
@@ -760,17 +760,12 @@ def test_reductions(split_every):
             offset = (6 * (n - 1)) / ((n - 2) * (n - 3))
             assert_eq(factor * dds.kurtosis() + offset, pds.kurtosis())
 
-            if PANDAS_GT_200:
-                # TODO: Remove this `if`-block once `axis=None` support is added.
-                # https://github.com/dask/dask/issues/9915
-                with pytest.raises(
-                    ValueError, match="`axis=None` isn't currently supported"
-                ):
-                    dds.kurtosis(axis=None)
-            else:
-                assert_eq(
-                    factor * dds.kurtosis(axis=None) + offset, pds.kurtosis(axis=None)
-                )
+            # TODO: Remove this `if`-block once `axis=None` support is added.
+            # https://github.com/dask/dask/issues/9915
+            with pytest.raises(
+                ValueError, match="`axis=None` isn't currently supported"
+            ):
+                dds.kurtosis(axis=None)
 
         with warnings.catch_warnings():
             warnings.simplefilter("ignore", RuntimeWarning)
@@ -818,20 +813,21 @@ def test_reductions(split_every):
             dds.mean(skipna=False, split_every=split_every), pds.mean(skipna=False)
         )
 
-    assert_dask_graph(ddf1.b.sum(split_every=split_every), "series-sum")
-    assert_dask_graph(ddf1.b.prod(split_every=split_every), "series-prod")
-    assert_dask_graph(ddf1.b.min(split_every=split_every), "series-min")
-    assert_dask_graph(ddf1.b.max(split_every=split_every), "series-max")
-    assert_dask_graph(ddf1.b.count(split_every=split_every), "series-count")
-    assert_dask_graph(ddf1.b.std(split_every=split_every), "series-std")
-    assert_dask_graph(ddf1.b.var(split_every=split_every), "series-var")
-    assert_dask_graph(ddf1.b.sem(split_every=split_every), "series-sem")
-    assert_dask_graph(ddf1.b.std(ddof=0, split_every=split_every), "series-std")
-    assert_dask_graph(ddf1.b.var(ddof=0, split_every=split_every), "series-var")
-    assert_dask_graph(ddf1.b.sem(ddof=0, split_every=split_every), "series-sem")
-    assert_dask_graph(ddf1.b.mean(split_every=split_every), "series-mean")
-    # nunique is performed using drop-duplicates
-    assert_dask_graph(ddf1.b.nunique(split_every=split_every), "drop-duplicates")
+    if not DASK_EXPR_ENABLED:
+        assert_dask_graph(ddf1.b.sum(split_every=split_every), "series-sum")
+        assert_dask_graph(ddf1.b.prod(split_every=split_every), "series-prod")
+        assert_dask_graph(ddf1.b.min(split_every=split_every), "series-min")
+        assert_dask_graph(ddf1.b.max(split_every=split_every), "series-max")
+        assert_dask_graph(ddf1.b.count(split_every=split_every), "series-count")
+        assert_dask_graph(ddf1.b.std(split_every=split_every), "series-std")
+        assert_dask_graph(ddf1.b.var(split_every=split_every), "series-var")
+        assert_dask_graph(ddf1.b.sem(split_every=split_every), "series-sem")
+        assert_dask_graph(ddf1.b.std(ddof=0, split_every=split_every), "series-std")
+        assert_dask_graph(ddf1.b.var(ddof=0, split_every=split_every), "series-var")
+        assert_dask_graph(ddf1.b.sem(ddof=0, split_every=split_every), "series-sem")
+        assert_dask_graph(ddf1.b.mean(split_every=split_every), "series-mean")
+        # nunique is performed using drop-duplicates
+        assert_dask_graph(ddf1.b.nunique(split_every=split_every), "drop-duplicates")
 
     # testing index
     assert_eq(ddf1.index.min(split_every=split_every), pdf1.index.min())
@@ -850,55 +846,82 @@ def test_reductions_timedelta(split_every):
     assert_eq(dds.count(split_every=split_every), ds.count())
 
 
-@pytest.mark.parametrize(
-    "frame,axis,out",
-    [
-        (
-            pd.DataFrame({"a": [1, 2, 3], "b": [4, 5, 6]}, index=[0, 1, 3]),
-            0,
-            pd.Series([], dtype="float64"),
-        ),
-        (
-            pd.DataFrame({"a": [1, 2, 3], "b": [4, 5, 6]}, index=[0, 1, 3]),
-            1,
-            pd.Series([], dtype="float64"),
-        ),
-        (pd.Series([1, 2.5, 6]), None, None),
-    ],
+@pytest.mark.skipif(
+    DASK_EXPR_ENABLED, reason="legacy, no longer supported in dask-expr"
 )
+@pytest.mark.parametrize("axis", [0, 1])
 @pytest.mark.parametrize(
-    "redfunc", ["sum", "prod", "product", "min", "max", "mean", "var", "std"]
+    "redfunc",
+    ["sum", "prod", "product", "min", "max", "mean", "var", "std", "all", "any"],
 )
-def test_reductions_out(frame, axis, out, redfunc):
+def test_reductions_out(axis, redfunc):
+    frame = pd.DataFrame({"a": [1, 2, 3], "b": [4, 5, 6]}, index=[0, 1, 3])
     dsk_in = dd.from_pandas(frame, 3)
-    dsk_out = dd.from_pandas(pd.Series([0]), 1).sum()
 
-    if out is not None:
-        dsk_out = dd.from_pandas(out, 3)
+    out = dd.from_pandas(pd.Series([], dtype="float64"), 3)
 
     np_redfunc = getattr(np, redfunc)
     pd_redfunc = getattr(frame.__class__, redfunc)
     dsk_redfunc = getattr(dsk_in.__class__, redfunc)
 
+    ctx = pytest.warns(FutureWarning, match=r"the 'out' keyword is deprecated")
+
     if redfunc in ["var", "std"]:
         # numpy has default ddof value 0 while
         # dask and pandas have 1, so ddof should be passed
         # explicitly when calling np.var(dask)
-        np_redfunc(dsk_in, axis=axis, ddof=1, out=dsk_out)
-    else:
-        ctx = contextlib.nullcontext()
-        if _numpy_125 and redfunc == "product":
-            ctx = pytest.warns(DeprecationWarning, match="`product` is deprecated")
         with ctx:
-            np_redfunc(dsk_in, axis=axis, out=dsk_out)
+            np_redfunc(dsk_in, axis=axis, ddof=1, out=out)
+    elif NUMPY_GE_125 and redfunc == "product" and out is None:
+        with pytest.warns(DeprecationWarning, match="`product` is deprecated"):
+            np_redfunc(dsk_in, axis=axis, out=out)
+    else:
+        with ctx:
+            np_redfunc(dsk_in, axis=axis, out=out)
 
-    assert_eq(dsk_out, pd_redfunc(frame, axis=axis))
+    assert_eq(out, pd_redfunc(frame, axis=axis))
 
-    dsk_redfunc(dsk_in, axis=axis, split_every=False, out=dsk_out)
-    assert_eq(dsk_out, pd_redfunc(frame, axis=axis))
+    with ctx:
+        dsk_redfunc(dsk_in, axis=axis, split_every=False, out=out)
+    assert_eq(out, pd_redfunc(frame, axis=axis))
 
-    dsk_redfunc(dsk_in, axis=axis, split_every=2, out=dsk_out)
-    assert_eq(dsk_out, pd_redfunc(frame, axis=axis))
+    with pytest.warns(FutureWarning, match="the 'out' keyword is deprecated"):
+        dsk_redfunc(dsk_in, axis=axis, split_every=2, out=out)
+    assert_eq(out, pd_redfunc(frame, axis=axis))
+
+
+@pytest.mark.parametrize("axis", [0, 1])
+@pytest.mark.parametrize(
+    "redfunc",
+    ["sum", "prod", "product", "min", "max", "mean", "var", "std", "all", "any"],
+)
+def test_reductions_numpy_dispatch(axis, redfunc):
+    pdf = pd.DataFrame({"a": [1, 2, 3], "b": [4, 5, 6]}, index=[0, 1, 3])
+    df = dd.from_pandas(pdf, 3)
+
+    if NUMPY_GE_200 and redfunc == "product":
+        with pytest.raises(
+            AttributeError, match="module 'numpy' has no attribute 'product'"
+        ):
+            np_redfunc = getattr(np, redfunc)
+        pytest.skip(reason="numpy>2 removed product -- users should move to prod")
+
+    np_redfunc = getattr(np, redfunc)
+    if redfunc in ("var", "std"):
+        # numpy has default ddof value 0 while
+        # dask and pandas have 1, so ddof should be passed
+        # explicitly when calling np.var(dask)
+        expect = np_redfunc(pdf, axis=axis, ddof=1)
+        actual = np_redfunc(df, axis=axis, ddof=1)
+    elif NUMPY_GE_125 and redfunc == "product" and not NUMPY_GE_200:
+        expect = np_redfunc(pdf, axis=axis)
+        with pytest.warns(DeprecationWarning, match="`product` is deprecated"):
+            actual = np_redfunc(df, axis=axis)
+    else:
+        expect = np_redfunc(pdf, axis=axis)
+        actual = np_redfunc(df, axis=axis)
+
+    assert_eq(expect, actual)
 
 
 @pytest.mark.parametrize("split_every", [False, 2])
@@ -930,25 +953,31 @@ def test_allany(split_every):
         pd.Series(np.random.choice([True, False], size=(100,))), 10
     )
 
-    # all
-    ddf.all(split_every=split_every, out=ddf_out_axis_default)
-    assert_eq(ddf_out_axis_default, df.all())
+    if not DASK_EXPR_ENABLED:
+        with pytest.warns(FutureWarning, match="the 'out' keyword is deprecated"):
+            ddf.all(split_every=split_every, out=ddf_out_axis_default)
+        assert_eq(ddf_out_axis_default, df.all())
 
-    ddf.all(axis=1, split_every=split_every, out=ddf_out_axis1)
-    assert_eq(ddf_out_axis1, df.all(axis=1))
+        with pytest.warns(FutureWarning, match="the 'out' keyword is deprecated"):
+            ddf.all(axis=1, split_every=split_every, out=ddf_out_axis1)
+        assert_eq(ddf_out_axis1, df.all(axis=1))
 
-    ddf.all(split_every=split_every, axis=0, out=ddf_out_axis_default)
-    assert_eq(ddf_out_axis_default, df.all(axis=0))
+        with pytest.warns(FutureWarning, match="the 'out' keyword is deprecated"):
+            ddf.all(split_every=split_every, axis=0, out=ddf_out_axis_default)
+        assert_eq(ddf_out_axis_default, df.all(axis=0))
 
-    # any
-    ddf.any(split_every=split_every, out=ddf_out_axis_default)
-    assert_eq(ddf_out_axis_default, df.any())
+        # any
+        with pytest.warns(FutureWarning, match="the 'out' keyword is deprecated"):
+            ddf.any(split_every=split_every, out=ddf_out_axis_default)
+        assert_eq(ddf_out_axis_default, df.any())
 
-    ddf.any(axis=1, split_every=split_every, out=ddf_out_axis1)
-    assert_eq(ddf_out_axis1, df.any(axis=1))
+        with pytest.warns(FutureWarning, match="the 'out' keyword is deprecated"):
+            ddf.any(axis=1, split_every=split_every, out=ddf_out_axis1)
+        assert_eq(ddf_out_axis1, df.any(axis=1))
 
-    ddf.any(split_every=split_every, axis=0, out=ddf_out_axis_default)
-    assert_eq(ddf_out_axis_default, df.any(axis=0))
+        with pytest.warns(FutureWarning, match="the 'out' keyword is deprecated"):
+            ddf.any(split_every=split_every, axis=0, out=ddf_out_axis_default)
+        assert_eq(ddf_out_axis_default, df.any(axis=0))
 
 
 @pytest.mark.parametrize("split_every", [False, 2])
@@ -1007,7 +1036,10 @@ def test_reduction_series_invalid_axis():
     meta = make_meta(
         {"a": "i8", "b": "i8"}, index=pd.Index([], "i8"), parent_meta=pd.DataFrame()
     )
-    ddf1 = dd.DataFrame(dsk, "x", meta, [0, 4, 9, 9])
+    if DASK_EXPR_ENABLED:
+        ddf1 = dd.repartition(pd.concat(dsk.values()), [0, 4, 9, 9])
+    else:
+        ddf1 = dd.DataFrame(dsk, "x", meta, [0, 4, 9, 9])
     pdf1 = ddf1.compute()
 
     for axis in [1, "columns"]:
@@ -1018,7 +1050,9 @@ def test_reduction_series_invalid_axis():
             pytest.raises(ValueError, lambda s=s, axis=axis: s.min(axis=axis))
             pytest.raises(ValueError, lambda s=s, axis=axis: s.max(axis=axis))
             # only count doesn't have axis keyword
-            pytest.raises(TypeError, lambda s=s, axis=axis: s.count(axis=axis))
+            pytest.raises(
+                (TypeError, ValueError), lambda s=s, axis=axis: s.count(axis=axis)
+            )
             pytest.raises(ValueError, lambda s=s, axis=axis: s.std(axis=axis))
             pytest.raises(ValueError, lambda s=s, axis=axis: s.var(axis=axis))
             pytest.raises(ValueError, lambda s=s, axis=axis: s.sem(axis=axis))
@@ -1029,6 +1063,9 @@ def test_reduction_series_invalid_axis():
 def test_reductions_non_numeric_dtypes():
     # test non-numric blocks
 
+    if DASK_EXPR_ENABLED:
+        pytest.skip(reason="no arrow strings yet")
+
     def check_raises(d, p, func):
         pytest.raises((TypeError, ValueError), lambda: getattr(d, func)().compute())
         pytest.raises((TypeError, ValueError), lambda: getattr(p, func)())
@@ -1101,7 +1138,10 @@ def test_reductions_frame(split_every):
     meta = make_meta(
         {"a": "i8", "b": "i8"}, index=pd.Index([], "i8"), parent_meta=pd.DataFrame()
     )
-    ddf1 = dd.DataFrame(dsk, "x", meta, [0, 4, 9, 9])
+    if DASK_EXPR_ENABLED:
+        ddf1 = dd.repartition(pd.concat(dsk.values()), [0, 4, 9, 9])
+    else:
+        ddf1 = dd.DataFrame(dsk, "x", meta, [0, 4, 9, 9])
     pdf1 = ddf1.compute()
 
     assert_eq(ddf1.sum(split_every=split_every), pdf1.sum())
@@ -1146,65 +1186,57 @@ def test_reductions_frame(split_every):
 
     pytest.raises(ValueError, lambda: ddf1.sum(axis="incorrect").compute())
 
-    # axis=None
-    if PANDAS_GT_140 and not PANDAS_GT_200:
-        ctx = pytest.warns(FutureWarning, match="axis=None")
-    else:
-        ctx = contextlib.nullcontext()
     # min
-    with ctx:
-        result = ddf1.min(axis=None, split_every=split_every)
-    with ctx:
-        expected = pdf1.min(axis=None)
+    result = ddf1.min(axis=None, split_every=split_every)
+    expected = pdf1.min(axis=None)
     assert_eq(result, expected)
     # max
-    with ctx:
-        result = ddf1.max(axis=None, split_every=split_every)
-    with ctx:
-        expected = pdf1.max(axis=None)
+    result = ddf1.max(axis=None, split_every=split_every)
+    expected = pdf1.max(axis=None)
     assert_eq(result, expected)
     # mean
-    with ctx:
-        result = ddf1.mean(axis=None, split_every=split_every)
-    with ctx:
-        expected = pdf1.mean(axis=None)
-    assert_eq(result, expected)
+    result = ddf1.mean(axis=None, split_every=split_every)
+    expected = pdf1.mean(axis=None)
+    assert_eq(result, expected, check_dtype=not DASK_EXPR_ENABLED)
 
-    # axis=0
-    assert_dask_graph(ddf1.sum(split_every=split_every), "dataframe-sum")
-    assert_dask_graph(ddf1.prod(split_every=split_every), "dataframe-prod")
-    assert_dask_graph(ddf1.min(split_every=split_every), "dataframe-min")
-    assert_dask_graph(ddf1.max(split_every=split_every), "dataframe-max")
-    assert_dask_graph(ddf1.count(split_every=split_every), "dataframe-count")
+    if not DASK_EXPR_ENABLED:
+        # axis=0
+        assert_dask_graph(ddf1.sum(split_every=split_every), "dataframe-sum")
+        assert_dask_graph(ddf1.prod(split_every=split_every), "dataframe-prod")
+        assert_dask_graph(ddf1.min(split_every=split_every), "dataframe-min")
+        assert_dask_graph(ddf1.max(split_every=split_every), "dataframe-max")
+        assert_dask_graph(ddf1.count(split_every=split_every), "dataframe-count")
 
-    # std, var, sem, and mean consist of moment_* operations
-    assert_dask_graph(ddf1.std(split_every=split_every), "dataframe-var")
-    assert_dask_graph(ddf1.std(split_every=split_every), "moment_chunk")
-    assert_dask_graph(ddf1.std(split_every=split_every), "moment_agg")
-    assert_dask_graph(ddf1.std(split_every=split_every), "values")
+        # std, var, sem, and mean consist of moment_* operations
+        assert_dask_graph(ddf1.std(split_every=split_every), "dataframe-var")
+        assert_dask_graph(ddf1.std(split_every=split_every), "moment_chunk")
+        assert_dask_graph(ddf1.std(split_every=split_every), "moment_agg")
+        assert_dask_graph(ddf1.std(split_every=split_every), "values")
 
-    assert_dask_graph(ddf1.var(split_every=split_every), "moment_chunk")
-    assert_dask_graph(ddf1.var(split_every=split_every), "moment_agg")
-    assert_dask_graph(ddf1.var(split_every=split_every), "values")
+        assert_dask_graph(ddf1.var(split_every=split_every), "moment_chunk")
+        assert_dask_graph(ddf1.var(split_every=split_every), "moment_agg")
+        assert_dask_graph(ddf1.var(split_every=split_every), "values")
 
-    assert_dask_graph(ddf1.sem(split_every=split_every), "dataframe-var")
-    assert_dask_graph(ddf1.sem(split_every=split_every), "moment_chunk")
-    assert_dask_graph(ddf1.sem(split_every=split_every), "moment_agg")
-    assert_dask_graph(ddf1.sem(split_every=split_every), "values")
+        assert_dask_graph(ddf1.sem(split_every=split_every), "dataframe-var")
+        assert_dask_graph(ddf1.sem(split_every=split_every), "moment_chunk")
+        assert_dask_graph(ddf1.sem(split_every=split_every), "moment_agg")
+        assert_dask_graph(ddf1.sem(split_every=split_every), "values")
 
-    assert_dask_graph(ddf1.mean(split_every=split_every), "dataframe-sum")
-    assert_dask_graph(ddf1.mean(split_every=split_every), "dataframe-count")
+        assert_dask_graph(ddf1.mean(split_every=split_every), "dataframe-sum")
+        assert_dask_graph(ddf1.mean(split_every=split_every), "dataframe-count")
 
-    # axis=1
-    assert_dask_graph(ddf1.sum(axis=1, split_every=split_every), "dataframe-sum")
-    assert_dask_graph(ddf1.prod(axis=1, split_every=split_every), "dataframe-prod")
-    assert_dask_graph(ddf1.min(axis=1, split_every=split_every), "dataframe-min")
-    assert_dask_graph(ddf1.max(axis=1, split_every=split_every), "dataframe-max")
-    assert_dask_graph(ddf1.count(axis=1, split_every=split_every), "dataframe-count")
-    assert_dask_graph(ddf1.std(axis=1, split_every=split_every), "dataframe-std")
-    assert_dask_graph(ddf1.var(axis=1, split_every=split_every), "dataframe-var")
-    assert_dask_graph(ddf1.sem(axis=1, split_every=split_every), "dataframe-sem")
-    assert_dask_graph(ddf1.mean(axis=1, split_every=split_every), "dataframe-mean")
+        # axis=1
+        assert_dask_graph(ddf1.sum(axis=1, split_every=split_every), "dataframe-sum")
+        assert_dask_graph(ddf1.prod(axis=1, split_every=split_every), "dataframe-prod")
+        assert_dask_graph(ddf1.min(axis=1, split_every=split_every), "dataframe-min")
+        assert_dask_graph(ddf1.max(axis=1, split_every=split_every), "dataframe-max")
+        assert_dask_graph(
+            ddf1.count(axis=1, split_every=split_every), "dataframe-count"
+        )
+        assert_dask_graph(ddf1.std(axis=1, split_every=split_every), "dataframe-std")
+        assert_dask_graph(ddf1.var(axis=1, split_every=split_every), "dataframe-var")
+        assert_dask_graph(ddf1.sem(axis=1, split_every=split_every), "dataframe-sem")
+        assert_dask_graph(ddf1.mean(axis=1, split_every=split_every), "dataframe-mean")
 
 
 @pytest.mark.parametrize(
@@ -1274,10 +1306,9 @@ def test_reductions_frame_dtypes(func, kwargs, numeric_only):
 
     ddf = dd.from_pandas(df, 3)
 
-    with check_numeric_only_deprecation():
-        expected = getattr(df, func)(**kwargs)
-        actual = getattr(ddf, func)(**kwargs)
-        assert_eq(expected, actual)
+    expected = getattr(df, func)(**kwargs)
+    actual = getattr(ddf, func)(**kwargs)
+    assert_eq(expected, actual)
 
 
 def test_count_numeric_only_axis_one():
@@ -1301,7 +1332,7 @@ def test_count_numeric_only_axis_one():
 
 
 @pytest.mark.parametrize(
-    "func", ["sum", "prod", "product", "min", "max", "count", "var"]
+    "func", ["sum", "prod", "product", "min", "max", "count", "std", "var", "quantile"]
 )
 def test_reductions_frame_dtypes_numeric_only_supported(func):
     df = pd.DataFrame(
@@ -1314,62 +1345,66 @@ def test_reductions_frame_dtypes_numeric_only_supported(func):
             "bool": [True, False] * 4,
         }
     )
+    npartitions = 3
+    if func == "quantile":
+        # bool doesn't work in pandas quantile
+        df = df.drop(columns="bool")
+        npartitions = 1  # https://github.com/dask/dask/issues/9227
 
-    ddf = dd.from_pandas(df, 3)
-    numeric_only_false_raises = ["sum", "prod", "product", "var"]
+    ddf = dd.from_pandas(df, npartitions)
+
+    numeric_only_false_raises = ["sum", "prod", "product", "std", "var", "quantile"]
 
     # `numeric_only=True` is always supported
     assert_eq(
         getattr(df, func)(numeric_only=True),
         getattr(ddf, func)(numeric_only=True),
     )
+    errors = (
+        (ValueError, TypeError)
+        if pa is None
+        else (ValueError, TypeError, ArrowNotImplementedError)
+    )
 
     # `numeric_only=False`
     if func in numeric_only_false_raises:
         with pytest.raises(
-            TypeError,
-            match="'DatetimeArray' with dtype datetime64.*|'DatetimeArray' does not implement reduction",
+            errors,
+            match="'DatetimeArray' with dtype datetime64.*|"
+            "'DatetimeArray' does not implement reduction|could not convert|"
+            "'ArrowStringArray' with dtype string"
+            "|unsupported operand|no kernel|not supported",
         ):
             getattr(ddf, func)(numeric_only=False)
 
-        warning = FutureWarning
     else:
         assert_eq(
             getattr(df, func)(numeric_only=False),
             getattr(ddf, func)(numeric_only=False),
         )
-        warning = None
 
     # `numeric_only` default value
-    if PANDAS_GT_200:
-        if func in numeric_only_false_raises:
-            with pytest.raises(
-                TypeError,
-                match="'DatetimeArray' with dtype datetime64.*|'DatetimeArray' does not implement reduction",
-            ):
-                getattr(ddf, func)()
-        else:
-            assert_eq(
-                getattr(df, func)(),
-                getattr(ddf, func)(),
-            )
-    elif PANDAS_GT_150:
-        with pytest.warns(warning, match="The default value of numeric_only"):
-            pd_result = getattr(df, func)()
-        with pytest.warns(warning, match="The default value of numeric_only"):
-            dd_result = getattr(ddf, func)()
-        assert_eq(pd_result, dd_result)
+    if func in numeric_only_false_raises:
+        with pytest.raises(
+            errors,
+            match="'DatetimeArray' with dtype datetime64.*|"
+            "'DatetimeArray' does not implement reduction|could not convert|"
+            "'ArrowStringArray' with dtype string"
+            "|unsupported operand|no kernel|not supported",
+        ):
+            getattr(ddf, func)()
     else:
-        if func == "var":
-            warning = None
-        with pytest.warns(warning, match="Dropping of nuisance"):
-            pd_result = getattr(df, func)()
-        with pytest.warns(warning, match="Dropping of nuisance"):
-            dd_result = getattr(ddf, func)()
-        assert_eq(pd_result, dd_result)
+        assert_eq(
+            getattr(df, func)(),
+            getattr(ddf, func)(),
+        )
 
-    df_numerics = df[["int", "float", "bool"]]
-    ddf_numerics = ddf[["int", "float", "bool"]]
+    num_cols = ["int", "float"]
+    if func != "quantile":
+        num_cols.append("bool")
+
+    df_numerics = df[num_cols]
+    ddf_numerics = ddf[num_cols]
 
     assert_eq(
         getattr(df_numerics, func)(),
@@ -1385,7 +1420,6 @@ def test_reductions_frame_dtypes_numeric_only_supported(func):
     "func",
     [
         "mean",
-        "std",
         "sem",
     ],
 )
@@ -1408,8 +1442,10 @@ def test_reductions_frame_dtypes_numeric_only(func):
         getattr(df, func)(**kwargs),
         getattr(ddf, func)(**kwargs),
     )
-    with pytest.raises(NotImplementedError, match="'numeric_only=False"):
-        getattr(ddf, func)(numeric_only=False)
+    if not DASK_EXPR_ENABLED:
+        # This won't raise in dask-expr. There are tests for it in the dask-expr repo.
+        with pytest.raises(NotImplementedError, match="'numeric_only=False"):
+            getattr(ddf, func)(numeric_only=False)
 
     assert_eq(df.sem(ddof=0, **kwargs), ddf.sem(ddof=0, **kwargs))
     assert_eq(df.std(ddof=0, **kwargs), ddf.std(ddof=0, **kwargs))
@@ -1419,14 +1455,18 @@ def test_reductions_frame_dtypes_numeric_only(func):
         df.var(skipna=False, ddof=0, **kwargs), ddf.var(skipna=False, ddof=0, **kwargs)
     )
 
-    # ------ only include numerics columns ------ #
-    assert_eq(df._get_numeric_data(), ddf._get_numeric_data())
+    if not DASK_EXPR_ENABLED:
+        # ------ only include numerics columns ------ #
+        # dask-expr doesn't have this method
+        assert_eq(df._get_numeric_data(), ddf._get_numeric_data())
 
     df_numerics = df[["int", "float", "bool"]]
     ddf_numerics = ddf[["int", "float", "bool"]]
 
-    assert_eq(df_numerics, ddf._get_numeric_data())
-    assert ddf_numerics._get_numeric_data().dask == ddf_numerics.dask
+    if not DASK_EXPR_ENABLED:
+        # dask-expr doesn't have this method
+        assert_eq(df_numerics, ddf._get_numeric_data())
+        assert ddf_numerics._get_numeric_data().dask == ddf_numerics.dask
 
     assert_eq(
         getattr(df_numerics, func)(),
@@ -1434,6 +1474,31 @@ def test_reductions_frame_dtypes_numeric_only(func):
     )
 
 
+@pytest.mark.parametrize("func", ["skew", "kurtosis"])
+def test_skew_kurt_numeric_only_false(func):
+    pytest.importorskip("scipy.stats")
+    df = pd.DataFrame(
+        {
+            "int": [1, 2, 3, 4, 5, 6, 7, 8],
+            "float": [1.0, 2.0, 3.0, 4.0, np.nan, 6.0, 7.0, 8.0],
+            "dt": [pd.NaT] + [datetime(2010, i, 1) for i in range(1, 8)],
+        }
+    )
+    ddf = dd.from_pandas(df, npartitions=2)
+
+    ctx = pytest.raises(TypeError, match="does not support|does not implement")
+
+    with ctx:
+        getattr(df, func)(numeric_only=False)
+    with ctx:
+        getattr(ddf, func)(numeric_only=False)
+
+    with ctx:
+        getattr(df, func)()
+    with ctx:
+        getattr(ddf, func)()
+
+
 @pytest.mark.parametrize("split_every", [False, 2])
 def test_reductions_frame_nan(split_every):
     df = pd.DataFrame(
@@ -1619,7 +1684,7 @@ def test_series_agg_with_min_count(method, min_count):
     if min_count == 0:
         assert result == 1
     else:
-        assert result is np.nan
+        assert result is np.nan or pd.isna(result)
 
 
 # Default absolute tolerance of 2000 nanoseconds
@@ -1651,33 +1716,21 @@ def test_datetime_std_creates_copy_cols(axis, numeric_only):
 
     kwargs = {} if numeric_only is None else {"numeric_only": numeric_only}
 
-    success = True
-    ctx = contextlib.nullcontext()
-    if numeric_only is False or (PANDAS_GT_200 and numeric_only is None):
-        ctx = pytest.raises(NotImplementedError, match="numeric_only")
-        success = False
-    elif numeric_only is None:
-        ctx = pytest.warns(FutureWarning, match="numeric_only")
-
     # Series test (same line twice to make sure data structure wasn't mutated)
     assert_eq(ddf["dt1"].std(**kwargs), pdf["dt1"].std(**kwargs))
     assert_eq(ddf["dt1"].std(**kwargs), pdf["dt1"].std(**kwargs))
 
     # DataFrame test (same line twice to make sure data structure wasn't mutated)
     expected = pdf.std(axis=axis, **kwargs)
-    result = None
-    with ctx:
-        result = ddf.std(axis=axis, **kwargs)
-    if success:
-        assert_near_timedeltas(result.compute(), expected)
+    result = ddf.std(axis=axis, **kwargs)
+    assert_near_timedeltas(result.compute(), expected)
 
     expected = pdf.std(axis=axis, **kwargs)
-    with ctx:
-        result = ddf.std(axis=axis, **kwargs)
-    if success:
-        assert_near_timedeltas(result.compute(), expected)
+    result = ddf.std(axis=axis, **kwargs)
+    assert_near_timedeltas(result.compute(), expected)
 
 
+@pytest.mark.filterwarnings("ignore::RuntimeWarning")
 @pytest.mark.parametrize("axis", [0, 1])
 @pytest.mark.parametrize("skipna", [False, True])
 @pytest.mark.parametrize("numeric_only", [True, False, None])
@@ -1718,30 +1771,13 @@ def test_datetime_std_with_larger_dataset(axis, skipna, numeric_only):
     kwargs = {} if numeric_only is None else {"numeric_only": numeric_only}
     kwargs["skipna"] = skipna
 
-    success = True
-    ctx = contextlib.nullcontext()
-    if numeric_only is False or (PANDAS_GT_200 and numeric_only is None):
-        ctx = pytest.raises(NotImplementedError, match="numeric_only")
-        success = False
-    elif numeric_only is None:
-        ctx = pytest.warns(FutureWarning, match="numeric_only")
-
-    result = None
-    expected = pdf[["dt1"]].std(axis=axis, **kwargs)
-    with ctx:
-        result = ddf[["dt1"]].std(axis=axis, **kwargs)
-    if success:
-        assert_near_timedeltas(result.compute(), expected)
-
     # Same thing but as Series. No axis, since axis=1 raises error
     assert_near_timedeltas(ddf["dt1"].std(**kwargs).compute(), pdf["dt1"].std(**kwargs))
 
     # Computation on full dataset
     expected = pdf.std(axis=axis, **kwargs)
-    with ctx:
-        result = ddf.std(axis=axis, **kwargs)
-    if success:
-        assert_near_timedeltas(result.compute(), expected)
+    result = ddf.std(axis=axis, **kwargs).compute()
+    assert_near_timedeltas(result, expected)
 
 
 @pytest.mark.parametrize("skipna", [False, True])
@@ -1764,27 +1800,24 @@ def test_datetime_std_across_axis1_null_results(skipna, numeric_only):
     kwargs = {} if numeric_only is None else {"numeric_only": numeric_only}
     kwargs["skipna"] = skipna
 
-    pctx = contextlib.nullcontext()
-    dctx = contextlib.nullcontext()
+    ctx = contextlib.nullcontext()
     success = True
-    if numeric_only is False or (PANDAS_GT_200 and numeric_only is None):
-        dctx = pytest.raises(NotImplementedError, match="numeric_only")
-        pctx = pytest.raises(TypeError)
+    if numeric_only is False or numeric_only is None:
+        ctx = pytest.raises(TypeError)
         success = False
     elif numeric_only is None:
-        dctx = pctx = pytest.warns(FutureWarning, match="numeric_only")
+        ctx = pytest.warns(FutureWarning, match="numeric_only")
 
     # Single column always results in NaT
     expected = pdf[["dt1"]].std(axis=1, **kwargs)
-    with dctx:
-        result = ddf[["dt1"]].std(axis=1, **kwargs)
+    result = ddf[["dt1"]].std(axis=1, **kwargs)
     if success:
         assert_eq(result, expected)
 
     # Mix of datetimes with other numeric types produces NaNs
-    with pctx:
+    with ctx:
         expected = pdf.std(axis=1, **kwargs)
-    with dctx:
+    with ctx:
         result = ddf.std(axis=1, **kwargs)
     if success:
         assert_eq(result, expected)
@@ -1807,45 +1840,67 @@ def test_datetime_std_across_axis1_null_results(skipna, numeric_only):
     ddf2 = dd.from_pandas(pdf2, 3)
 
     expected = pdf2.std(axis=1, **kwargs)
-    with dctx:
-        result = ddf2.std(axis=1, **kwargs)
+    result = ddf2.std(axis=1, **kwargs)
     if success:
         assert_eq(result, expected)
 
 
-@pytest.mark.parametrize(
-    "dtypes",
-    [
-        pytest.param(
-            ("int64[pyarrow]", "float64[pyarrow]"),
-            marks=pytest.mark.skipif(
-                pa is None or not PANDAS_GT_150,
-                reason="requires pyarrow installed and ArrowDtype",
-            ),
-        ),
-        ("Int64", "Float64"),
-    ],
-)
-@pytest.mark.parametrize("func", ["std", "var", "skew"])
-def test_reductions_with_pandas_and_arrow_ea(dtypes, func):
-    if func in ["skew"]:
-        pytest.importorskip("scipy")
-        if "pyarrow" in dtypes[0]:
-            pytest.xfail("skew not implemented for arrow dtypes")
-
-    pdf = pd.DataFrame({"a": [1, 2, 3, 4], "b": [4, 5, 6, 7]}).astype(
-        {"a": dtypes[0], "b": dtypes[1]}
-    )
-    ddf = dd.from_pandas(pdf, npartitions=2)
-    pd_result = getattr(pdf, func)()
-    dd_result = getattr(ddf, func)()
-
-    assert_eq(dd_result, pd_result, check_dtype=False)  # _meta is wrongly NA
-
-
 def test_std_raises_on_index():
     with pytest.raises(
-        NotImplementedError,
-        match="`std` is only supported with objects that are Dataframes or Series",
+        (NotImplementedError, AttributeError),
+        match="`std` is only supported with objects that are Dataframes or Series|has no attribute",
     ):
         dd.from_pandas(pd.DataFrame({"test": [1, 2]}), npartitions=2).index.std()
+
+
+def test_std_raises_with_arrow_string_ea():
+    pa = pytest.importorskip("pyarrow")
+    ser = pd.Series(["a", "b", "c"], dtype=pd.ArrowDtype(pa.string()))
+    ds = dd.from_pandas(ser, npartitions=2)
+    with pytest.raises(ValueError, match="`std` not supported with string series"):
+        ds.std()
+
+
+@pytest.mark.parametrize(
+    "dtype",
+    [
+        pytest.param(
+            "int64[pyarrow]",
+            marks=pytest.mark.skipif(pa is None, reason="requires pyarrow installed"),
+        ),
+        pytest.param(
+            "float64[pyarrow]",
+            marks=pytest.mark.skipif(pa is None, reason="requires pyarrow installed"),
+        ),
+        "Int64",
+        "Int32",
+        "Float64",
+        "UInt64",
+    ],
+)
+@pytest.mark.parametrize("func", ["std", "var", "skew", "kurtosis"])
+def test_reductions_with_pandas_and_arrow_ea(dtype, func):
+    if func in ["skew", "kurtosis"]:
+        pytest.importorskip("scipy")
+        if "pyarrow" in dtype:
+            pytest.xfail("skew/kurtosis not implemented for arrow dtypes")
+
+    ser = pd.Series([1, 2, 3, 4], dtype=dtype)
+    ds = dd.from_pandas(ser, npartitions=2)
+    pd_result = getattr(ser, func)()
+    dd_result = getattr(ds, func)()
+    if func == "kurtosis":
+        n = ser.shape[0]
+        factor = ((n - 1) * (n + 1)) / ((n - 2) * (n - 3))
+        offset = (6 * (n - 1)) / ((n - 2) * (n - 3))
+        dd_result = factor * dd_result + offset
+    # _meta is wrongly NA
+    assert_eq(dd_result, pd_result, check_dtype=False)
+
+
+def test_quantile_arrow_dtype():
+    pdf = pd.DataFrame({"foo": [1, 1, 1, 1, 1, 1]}).convert_dtypes(
+        dtype_backend="pyarrow"
+    )
+    df = dd.from_pandas(pdf, npartitions=2)
+    assert_eq(df.quantile(0.25), pdf.quantile(0.25), check_dtype=False)
