@@ -11,7 +11,7 @@ from packaging.version import Version
 
 import dask
 import dask.dataframe as dd
-from dask.dataframe._compat import PANDAS_GE_200, tm
+from dask.dataframe._compat import PANDAS_GE_300, tm
 from dask.dataframe.core import apply_and_enforce
 from dask.dataframe.utils import (
     UNKNOWN_CATEGORIES,
@@ -273,11 +273,7 @@ def test_meta_nonempty_index():
     idx = pd.Index([1], name="foo", dtype="int")
     res = meta_nonempty(idx)
     assert type(res) is type(idx)
-    if PANDAS_GE_200:
-        assert res.dtype == np.int_
-    else:
-        # before pandas 2.0, index dtypes were only x64
-        assert res.dtype == "int64"
+    assert res.dtype == np.int_
     assert res.name == idx.name
 
     idx = pd.Index(["a"], name="foo")
@@ -285,20 +281,20 @@ def test_meta_nonempty_index():
     assert type(res) is pd.Index
     assert res.name == idx.name
 
-    idx = pd.DatetimeIndex(["1970-01-01"], freq="d", tz="America/New_York", name="foo")
+    idx = pd.DatetimeIndex(["1970-01-01"], freq="D", tz="America/New_York", name="foo")
     res = meta_nonempty(idx)
     assert type(res) is pd.DatetimeIndex
     assert res.tz == idx.tz
     assert res.freq == idx.freq
     assert res.name == idx.name
 
-    idx = pd.PeriodIndex(["1970-01-01"], freq="d", name="foo")
+    idx = pd.PeriodIndex(["1970-01-01"], freq="D", name="foo")
     res = meta_nonempty(idx)
     assert type(res) is pd.PeriodIndex
     assert res.freq == idx.freq
     assert res.name == idx.name
 
-    idx = pd.TimedeltaIndex([pd.Timedelta(1, "D")], freq="d", name="foo")
+    idx = pd.TimedeltaIndex([pd.Timedelta(1, "D")], freq="D", name="foo")
     res = meta_nonempty(idx)
     assert type(res) is pd.TimedeltaIndex
     assert res.freq == idx.freq
@@ -431,11 +427,12 @@ def test_check_meta():
     df2 = df[["a", "b", "d", "e"]]
     with pytest.raises(ValueError) as err:
         check_meta(df2, meta2, funcname="from_delayed")
+    frame = "pandas.core.frame.DataFrame" if not PANDAS_GE_300 else "pandas.DataFrame"
 
     exp = (
         "Metadata mismatch found in `from_delayed`.\n"
         "\n"
-        "Partition type: `pandas.core.frame.DataFrame`\n"
+        f"Partition type: `{frame}`\n"
         "+--------+----------+----------+\n"
         "| Column | Found    | Expected |\n"
         "+--------+----------+----------+\n"
@@ -681,12 +678,8 @@ def test_pyarrow_strings_enabled():
     except ImportError:
         pa = None
 
-    # If `pandas>=2` and `pyarrow>=12` are installed, then default to using pyarrow strings
-    if (
-        PANDAS_GE_200
-        and pa is not None
-        and Version(pa.__version__) >= Version("12.0.0")
-    ):
+    # If `pyarrow>=12` are installed, then default to using pyarrow strings
+    if pa is not None and Version(pa.__version__) >= Version("12.0.0"):
         assert pyarrow_strings_enabled() is True
     else:
         assert pyarrow_strings_enabled() is False
