@@ -21,7 +21,7 @@ from dask.dataframe import (  # noqa: F401 register pandas extension types
     _dtypes,
     methods,
 )
-from dask.dataframe._compat import PANDAS_GE_150, tm  # noqa: F401
+from dask.dataframe._compat import tm  # noqa: F401
 from dask.dataframe.dispatch import (  # noqa : F401
     is_categorical_dtype_dispatch,
     make_meta,
@@ -849,7 +849,7 @@ def get_numeric_only_kwargs(numeric_only: bool | NoDefault) -> dict:
 
 
 def check_numeric_only_valid(numeric_only: bool | NoDefault, name: str) -> dict:
-    if PANDAS_GE_150 and numeric_only is not no_default:
+    if numeric_only is not no_default:
         return {"numeric_only": numeric_only}
     elif numeric_only is no_default:
         return {}
