@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import pickle
 from collections import namedtuple
 
@@ -8,12 +10,16 @@ from dask.core import (
     get,
     get_dependencies,
     get_deps,
+    getcycle,
     has_tasks,
+    ishashable,
+    iskey,
     istask,
     literal,
     preorder_traversal,
     quote,
     subs,
+    validate_key,
 )
 from dask.utils_test import GetFunctionTestMixin, add, inc
 
@@ -29,6 +35,51 @@ def contains(a, b):
     return all(a.get(k) == v for k, v in b.items())
 
 
+def test_ishashable():
+    class C:
+        pass
+
+    assert ishashable("x")
+    assert ishashable(1)
+    assert ishashable(C())
+    assert ishashable((1, 2))
+    assert not ishashable([1, 2])
+    assert not ishashable({1: 2})
+
+
+def test_iskey():
+    class C:
+        pass
+
+    assert iskey("x")
+    assert iskey(1)
+    assert not iskey(C())  # Custom hashables can't be dask keys
+    assert not iskey((C(),))
+    assert iskey((1, 2))
+    assert iskey(())
+    assert iskey(("x",))
+    assert not iskey([1, 2])
+    assert not iskey({1, 2})
+    assert not iskey({1: 2})
+
+
+def test_iskey_numpy_types():
+    np = pytest.importorskip("numpy")
+    one = np.int64(1)
+    assert not iskey(one)
+    assert not iskey(("foo", one))
+
+
+def test_validate_key():
+    validate_key(1)
+    validate_key(("x", 1))
+    with pytest.raises(TypeError, match="Unexpected key type.*list"):
+        validate_key(["x", 1])
+
+    with pytest.raises(TypeError, match="unexpected key type at index=1"):
+        validate_key((2, int))
+
+
 def test_istask():
     assert istask((inc, 1))
     assert not istask(1)
@@ -227,18 +278,9 @@ def test_subs_with_surprisingly_friendly_eq():
         assert subs(df, "x", 1) is df
 
 
-def test_subs_unexpected_hashable_key():
-    class UnexpectedButHashable:
-        def __init__(self):
-            self.name = "a"
-
-        def __hash__(self):
-            return hash(self.name)
-
-        def __eq__(self, other):
-            return isinstance(other, UnexpectedButHashable)
-
-    assert subs((id, UnexpectedButHashable()), UnexpectedButHashable(), 1) == (id, 1)
+def test_subs_arbitrary_key():
+    key = (1.2, "foo", (3,))
+    assert subs((id, key), key, 1) == (id, 1)
 
 
 def test_quote():
@@ -251,3 +293,32 @@ def test_quote():
 def test_literal_serializable():
     l = literal((add, 1, 2))
     assert pickle.loads(pickle.dumps(l)).data == (add, 1, 2)
+
+
+def test_getcycle():
+    dsk = {
+        0: [7, 13, 7, 9, 13, 3, 9, 18, 18, 17],
+        1: [14, 14, 12, 1, 9, 16, 4, 5, 9, 8],
+        2: [3, 1, 7, 7, 2, 0, 0, 6, 3, 2],
+        3: [4, 8, 3, 14, 15, 19, 14, 1, 9, 1],
+        4: [9, 13, 19, 4, 16, 8, 11, 1, 16, 1],
+        5: [9, 8, 12, 13, 10, 13, 19, 3, 18, 18],
+        6: [10, 2, 13, 16, 3, 12, 7, 16, 5, 17],
+        7: [16, 8, 6, 4, 4, 10, 3, 1, 13, 10],
+        8: [11, 4, 12, 10, 14, 6, 18, 15, 16, 12],
+        9: [17, 18, 5, 16, 19, 16, 3, 6, 16, 18],
+    }
+    assert len(getcycle(dsk, list(dsk))) <= 3  # 7->6->7
+    dsk = {
+        0: [1, 27, 6, 25, 30, 16, 1, 1, 35, 17],
+        1: [35, 22, 21, 31, 2, 28, 36, 0, 29, 29],
+        2: [14, 27, 10, 1, 38, 18, 28, 28, 6, 0],
+        3: [0, 37, 7, 16, 38, 28, 34, 13, 30, 10],
+        4: [22, 22, 27, 13, 29, 36, 22, 9, 39, 19],
+        5: [38, 7, 18, 17, 33, 5, 29, 11, 23, 30],
+        6: [3, 30, 28, 38, 4, 13, 14, 27, 29, 38],
+        7: [22, 27, 12, 2, 22, 16, 34, 15, 18, 16],
+        8: [36, 21, 24, 22, 28, 38, 21, 2, 4, 24],
+        9: [38, 32, 38, 7, 31, 34, 39, 20, 30, 18],
+    }
+    assert len(getcycle(dsk, list(dsk))) <= 4  # 0->1->2->0
