@@ -1,16 +1,22 @@
+from __future__ import annotations
+
 import os
+import threading
 import xml.etree.ElementTree
 from collections.abc import Set
+from concurrent.futures import ThreadPoolExecutor
 
 import pytest
 
 import dask
+from dask.base import tokenize
 from dask.blockwise import Blockwise, blockwise_token
 from dask.highlevelgraph import HighLevelGraph, Layer, MaterializedLayer, to_graphviz
 from dask.utils_test import inc
 
 
 def test_visualize(tmpdir):
+    pytest.importorskip("numpy")
     pytest.importorskip("graphviz")
     da = pytest.importorskip("dask.array")
     fn = str(tmpdir)
@@ -34,6 +40,7 @@ def test_basic():
 
 
 def test_keys_values_items_to_dict_methods():
+    pytest.importorskip("numpy")
     da = pytest.importorskip("dask.array")
     a = da.ones(10, chunks=(5,))
     b = a + 1
@@ -151,16 +158,18 @@ def annot_map_fn(key):
     ],
 )
 def test_single_annotation(annotation):
+    pytest.importorskip("numpy")
     da = pytest.importorskip("dask.array")
     with dask.annotate(**annotation):
         A = da.ones((10, 10), chunks=(5, 5))
 
     alayer = A.__dask_graph__().layers[A.name]
     assert alayer.annotations == annotation
-    assert dask.config.get("annotations", None) is None
+    assert not dask.get_annotations()
 
 
 def test_multiple_annotations():
+    pytest.importorskip("numpy")
     da = pytest.importorskip("dask.array")
     with dask.annotate(block_id=annot_map_fn):
         with dask.annotate(resources={"GPU": 1}):
@@ -170,7 +179,7 @@ def test_multiple_annotations():
 
     C = B + 1
 
-    assert dask.config.get("annotations", None) is None
+    assert not dask.get_annotations()
 
     alayer = A.__dask_graph__().layers[A.name]
     blayer = B.__dask_graph__().layers[B.name]
@@ -180,6 +189,16 @@ def test_multiple_annotations():
     assert clayer.annotations is None
 
 
+def test_annotation_cleared_on_error():
+    with dask.annotate(x=1):
+        with pytest.raises(ZeroDivisionError):
+            with dask.annotate(x=2):
+                assert dask.get_annotations() == {"x": 2}
+                1 / 0
+        assert dask.get_annotations() == {"x": 1}
+    assert not dask.get_annotations()
+
+
 def test_materializedlayer_cull_preserves_annotations():
     layer = MaterializedLayer(
         {"a": 42, "b": 3.14},
@@ -191,13 +210,33 @@ def test_materializedlayer_cull_preserves_annotations():
     assert culled_layer.annotations == {"foo": "bar"}
 
 
+def test_annotations_leak():
+    """Annotations shouldn't leak between threads.
+    See https://github.com/dask/dask/issues/10340."""
+    b1 = threading.Barrier(2)
+    b2 = threading.Barrier(2)
+
+    def f(n):
+        with dask.annotate(foo=n):
+            b1.wait()
+            out = dask.get_annotations()
+            b2.wait()
+            return out
+
+    with ThreadPoolExecutor(2) as ex:
+        f1 = ex.submit(f, 1)
+        f2 = ex.submit(f, 2)
+        result = [f1.result(), f2.result()]
+    assert result == [{"foo": 1}, {"foo": 2}]
+
+
 @pytest.mark.parametrize("flat", [True, False])
 def test_blockwise_cull(flat):
-    da = pytest.importorskip("dask.array")
     np = pytest.importorskip("numpy")
+    da = pytest.importorskip("dask.array")
     if flat:
         # Simple "flat" mapping between input and
-        # outut indices
+        # output indices
         x = da.from_array(np.arange(40).reshape((4, 10)), (2, 4)) + 100
     else:
         # Complex mapping between input and output
@@ -249,6 +288,7 @@ def test_len_does_not_materialize():
 
 
 def test_node_tooltips_exist():
+    pytest.importorskip("numpy")
     da = pytest.importorskip("dask.array")
     pytest.importorskip("graphviz")
 
@@ -266,3 +306,13 @@ def test_node_tooltips_exist():
             end = layer.find('"', start)
             tooltip = layer[start:end]
             assert len(tooltip) > 0
+
+
+def test_tokenize_hlg():
+    import dask.bag as db
+
+    a = db.from_sequence(list(range(10)), npartitions=2).max()
+    b = db.from_sequence(list(range(10)), npartitions=2).max()
+    c = db.from_sequence(list(range(10)), npartitions=3).max()
+    assert tokenize(a.dask) == tokenize(b.dask)
+    assert tokenize(a.dask) != tokenize(c.dask)
